Documentation
¶
Overview ¶
Package tls contains helper functions for generating Bootz server TLS configurations.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LogPeerTLSCertificate ¶
func LogPeerTLSCertificate(state tls.ConnectionState) error
LogPeerTLSCertificate prints details about the peer's TLS certificate for debugging.
Types ¶
type Opts ¶
type Opts struct {
// The private key of the CA that will sign the server's TLS certificate.
CAPrivateKey crypto.PrivateKey
// The certificate of the CA that will be used to generate the server's TLS cert.
CACert *x509.Certificate
// The IP address of the server. This will be used to generate the TLS cert.
IPAddress net.IP
// The x509 Cert Pool of IDevID CAs. If a client present a certificate, it must be
// signed by one of these.
ClientCAs *x509.CertPool
// The server cert's subject.
ServerCertSubject *pkix.Name
}
Opts define all parameters needed to generate a Bootz server TLS config.
Click to show internal directories.
Click to hide internal directories.